<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Form Recipients /////////////////////////
// Buttons:
define('FORM_RECIPIENTS_HEADING', "Edit Form Tatanggap");
define('FORM_RECIPIENTS_EDIT_FORM_RECIPIENTS_BTN', "Edit Form Tatanggap");
// Console Text:
define('FORM_RECIPIENTS_FORM_PAGE', "Form Page");
define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Maaari mong itakda ang higit sa isang tatanggap sa pamamagitan ng paghihiwalay ng mga email na may mga kuwit.");
// Popup Messages:
define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Sine-save ang tatanggap ...");
define('VIEW_FORM_TABLES_HEADING', "Tingnan ang Form Table");
define('VIEW_FORM_TABLES_BTN', "Tingnan ang Form Table");
define('VIEW_FORM_TABLES_SELECT_TABLE', "Pumili ng mga Tables to View");
define('VIEW_FORM_TABLES_FILTER_READ', "Filter Read Messages");
?>